pub struct AuthRuntime { /* private fields */ }Implementations
Sourceimpl AuthRuntime
impl AuthRuntime
pub async fn from_process(config: AuthConfig) -> Result<Self, AuthFailure>
Sourcepub async fn from_isolated_state(
config: AuthConfig,
) -> Result<Self, AuthFailure>
pub async fn from_isolated_state( config: AuthConfig, ) -> Result<Self, AuthFailure>
Start an embedded relay with an administrator key owned only by its state directory.
This deliberately leaves the process credential untouched because the containing UI uses that credential for its outbound register, connect, status, and stream connections.
pub async fn start( admin_key: AesKeyType, config: AuthConfig, ) -> Result<Self, AuthFailure>
pub async fn shutdown_actor(&self)
pub async fn abort_actor(&self) -> Result<(), AuthFailure>
pub fn config(&self) -> &AuthConfig
pub fn admin_key(&self) -> Result<AesKeyType, AuthFailure>
pub fn derive_key(&self, key_id: KeyId) -> Result<AesKeyType, AuthFailure>
pub fn derive_previous_key(&self, key_id: KeyId) -> Option<AesKeyType>
pub fn authenticate_presented( &self, key_id: KeyId, presented_key: &AesKeyType, ) -> Result<AuthContext, AuthFailure>
pub fn legacy_protocol_allowed(&self) -> Result<bool, AuthFailure>
pub fn record_legacy_connection( &self, ) -> Result<LegacyConnectionGuard, AuthFailure>
pub async fn claim_admin_mutation( &self, authorization: &AuthContext, fingerprint: [u8; 32], client_timestamp: u64, ) -> Result<(), AuthFailure>
pub async fn issue( &self, authorization: &AuthContext, ttl: Duration, label: Option<String>, ) -> Result<IssuedTemporaryKey, AuthFailure>
pub async fn list( &self, authorization: &AuthContext, page: u32, page_size: u16, ) -> Result<KeyPage, AuthFailure>
pub async fn show( &self, authorization: &AuthContext, key_id: KeyId, reveal: bool, ) -> Result<IssuedTemporaryKey, AuthFailure>
pub async fn renew( &self, authorization: &AuthContext, key_id: KeyId, ttl: Duration, ) -> Result<IssuedTemporaryKey, AuthFailure>
pub async fn revoke( &self, authorization: &AuthContext, key_id: KeyId, ) -> Result<TemporaryKeyMetadata, AuthFailure>
pub async fn gc(&self, authorization: &AuthContext) -> Result<u64, AuthFailure>
pub async fn reset( &self, authorization: &AuthContext, ) -> Result<(), AuthFailure>
pub async fn rotate_root( &self, authorization: &AuthContext, new_key: AesKeyType, ) -> Result<(), AuthFailure>
pub async fn set_legacy_protocol( &self, authorization: &AuthContext, policy: LegacyProtocolPolicy, ) -> Result<(), AuthFailure>
pub async fn status( &self, authorization: &AuthContext, ) -> Result<AuthStatus, AuthFailure>
pub async fn audit_admin( &self, authorization: &AuthContext, action: impl Into<String>, key_id: Option<KeyId>, detail: Option<String>, ) -> Result<(), AuthFailure>